==> qtjambi-charts-debuginfo-windows-x64-6.6.1.jar: sources/QtJambiCharts/QXYModelMapper_shell.h <==
#ifndef QXYMODELMAPPER_SHELL_H
#define QXYMODELMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qxymodelmapper.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qxyseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QXYModelMapper_shell : public QXYModelMapper, public QtJambiShellInterface
{
public:
    QXYModelMapper_shell(QObject* parent0 = nullptr);
    ~QXYModelMapper_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QXYModelMapper_access : public QXYModelMapper
{
    jint __qt_count(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_first(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_model(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_orientation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_series(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setCount_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint count0);
    void __qt_setFirst_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint first0);
    void __qt_setModel_QAbstractItemModel_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID model0);
    void __qt_setOrientation_Qt_Orientation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint orientation0);
    void __qt_setSeries_QXYSeries_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID series0);
    void __qt_setXSection_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint xSection0);
    void __qt_setYSection_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint ySection0);
    jint __qt_xSection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_ySection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QXYMODELMAPPER_SHELL_H

==> qtjambi-charts-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCharts/QXYModelMapper_shell.h <==
#ifndef QXYMODELMAPPER_SHELL_H
#define QXYMODELMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qxymodelmapper.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qxyseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QXYModelMapper_shell : public QXYModelMapper, public QtJambiShellInterface
{
public:
    QXYModelMapper_shell(QObject* parent0 = nullptr);
    ~QXYModelMapper_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QXYModelMapper_access : public QXYModelMapper
{
    jint __qt_count_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_first_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_model_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_orientation_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_series_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setCount_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint count0);
    void __qt_setFirst_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint first0);
    void __qt_setModel_QAbstractItemModel_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID model0);
    void __qt_setOrientation_Qt_Orientation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint orientation0);
    void __qt_setSeries_QXYSeries_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID series0);
    void __qt_setXSection_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint xSection0);
    void __qt_setYSection_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint ySection0);
    jint __qt_xSection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_ySection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QXYMODELMAPPER_SHELL_H
